@@ -13,7 +13,7 @@
  ****************************************/
 
 #include "grib_api_internal.h"
-#include <ctype.h>
+#include <cctype>
 
 #if GRIB_PTHREADS
 static pthread_once_t once    = PTHREAD_ONCE_INIT;
@@ -79,7 +79,6 @@ static int value_count(grib_accessor*, long*);
 static void destroy(grib_context*, grib_accessor*);
 static void dump(grib_accessor*, grib_dumper*);
 static void init(grib_accessor*, const long, grib_arguments*);
-static void init_class(grib_accessor_class*);
 
 typedef struct grib_accessor_codetable
 {
@@ -104,32 +103,32 @@ static grib_accessor_class _grib_accessor_class_codetable = {
     "codetable",                      /* name */
     sizeof(grib_accessor_codetable),  /* size */
     0,                           /* inited */
-    &init_class,                 /* init_class */
+    0,                           /* init_class */
     &init,                       /* init */
     0,                  /* post_init */
-    &destroy,                    /* free mem */
-    &dump,                       /* describes himself */
-    0,                /* get length of section */
+    &destroy,                    /* destroy */
+    &dump,                       /* dump */
+    0,                /* next_offset */
     0,              /* get length of string */
     &value_count,                /* get number of values */
     0,                 /* get number of bytes */
     0,                /* get offset to bytes */
     &get_native_type,            /* get native type */
     0,                /* get sub_section */
-    0,               /* grib_pack procedures long */
-    0,                 /* grib_pack procedures long */
-    0,                  /* grib_pack procedures long */
-    &unpack_long,                /* grib_unpack procedures long */
-    0,                /* grib_pack procedures double */
-    0,                 /* grib_pack procedures float */
-    0,              /* grib_unpack procedures double */
-    0,               /* grib_unpack procedures float */
-    &pack_string,                /* grib_pack procedures string */
-    &unpack_string,              /* grib_unpack procedures string */
-    0,          /* grib_pack array procedures string */
-    0,        /* grib_unpack array procedures string */
-    0,                 /* grib_pack procedures bytes */
-    0,               /* grib_unpack procedures bytes */
+    0,               /* pack_missing */
+    0,                 /* is_missing */
+    0,                  /* pack_long */
+    &unpack_long,                /* unpack_long */
+    0,                /* pack_double */
+    0,                 /* pack_float */
+    0,              /* unpack_double */
+    0,               /* unpack_float */
+    &pack_string,                /* pack_string */
+    &unpack_string,              /* unpack_string */
+    0,          /* pack_string_array */
+    0,        /* unpack_string_array */
+    0,                 /* pack_bytes */
+    0,               /* unpack_bytes */
     &pack_expression,            /* pack_expression */
     0,              /* notify_change */
     0,                /* update_size */
@@ -138,10 +137,10 @@ static grib_accessor_class _grib_accessor_class_codetable = {
     0,      /* nearest_smaller_value */
     0,                       /* next accessor */
     0,                    /* compare vs. another accessor */
-    0,      /* unpack only ith value */
-    0,       /* unpack only ith value */
-    0,  /* unpack a given set of elements */
-    0,   /* unpack a given set of elements */
+    0,      /* unpack only ith value (double) */
+    0,       /* unpack only ith value (float) */
+    0,  /* unpack a given set of elements (double) */
+    0,   /* unpack a given set of elements (float) */
     0,     /* unpack a subarray */
     0,                      /* clear */
     0,                 /* clone accessor */
@@ -150,45 +149,9 @@ static grib_accessor_class _grib_accessor_class_codetable = {
 
 grib_accessor_class* grib_accessor_class_codetable = &_grib_accessor_class_codetable;
 
-
-static void init_class(grib_accessor_class* c)
-{
-    c->next_offset    =    (*(c->super))->next_offset;
-    c->string_length    =    (*(c->super))->string_length;
-    c->byte_count    =    (*(c->super))->byte_count;
-    c->byte_offset    =    (*(c->super))->byte_offset;
-    c->sub_section    =    (*(c->super))->sub_section;
-    c->pack_missing    =    (*(c->super))->pack_missing;
-    c->is_missing    =    (*(c->super))->is_missing;
-    c->pack_long    =    (*(c->super))->pack_long;
-    c->pack_double    =    (*(c->super))->pack_double;
-    c->pack_float    =    (*(c->super))->pack_float;
-    c->unpack_double    =    (*(c->super))->unpack_double;
-    c->unpack_float    =    (*(c->super))->unpack_float;
-    c->pack_string_array    =    (*(c->super))->pack_string_array;
-    c->unpack_string_array    =    (*(c->super))->unpack_string_array;
-    c->pack_bytes    =    (*(c->super))->pack_bytes;
-    c->unpack_bytes    =    (*(c->super))->unpack_bytes;
-    c->notify_change    =    (*(c->super))->notify_change;
-    c->update_size    =    (*(c->super))->update_size;
-    c->preferred_size    =    (*(c->super))->preferred_size;
-    c->resize    =    (*(c->super))->resize;
-    c->nearest_smaller_value    =    (*(c->super))->nearest_smaller_value;
-    c->next    =    (*(c->super))->next;
-    c->compare    =    (*(c->super))->compare;
-    c->unpack_double_element    =    (*(c->super))->unpack_double_element;
-    c->unpack_float_element    =    (*(c->super))->unpack_float_element;
-    c->unpack_double_element_set    =    (*(c->super))->unpack_double_element_set;
-    c->unpack_float_element_set    =    (*(c->super))->unpack_float_element_set;
-    c->unpack_double_subarray    =    (*(c->super))->unpack_double_subarray;
-    c->clear    =    (*(c->super))->clear;
-    c->make_clone    =    (*(c->super))->make_clone;
-}
-
 /* END_CLASS_IMP */
 
-static int grib_load_codetable(grib_context* c, const char* filename,
-                               const char* recomposed_name, size_t size, grib_codetable* t);
+static int grib_load_codetable(grib_context* c, const char* filename, const char* recomposed_name, size_t size, grib_codetable* t);
 
 static void init(grib_accessor* a, const long len, grib_arguments* params)
 {
@@ -197,7 +160,7 @@ static void init(grib_accessor* a, const long len, grib_arguments* params)
     grib_handle* hand             = grib_handle_of_accessor(a);
     grib_accessor_codetable* self = (grib_accessor_codetable*)a;
     grib_action* act              = (grib_action*)(a->creator);
-    DebugAssert(len == self->nbytes);
+    DEBUG_ASSERT(len == self->nbytes);
 
     if (new_len == 0) {
         /* ECC-485: When the codetable length is 0, it means we are passing
@@ -305,14 +268,14 @@ static void dump_codetable(grib_codetable* atable)
     }
 }
 #endif
-static grib_codetable* load_table(grib_accessor_codetable* self)
+static grib_codetable* load_table(grib_accessor* a)
 {
+    grib_accessor_codetable* self = (grib_accessor_codetable*)a;
     size_t size           = 0;
     grib_handle* h        = ((grib_accessor*)self)->parent->h;
     grib_context* c       = h->context;
     grib_codetable* t     = NULL;
     grib_codetable* next  = NULL;
-    grib_accessor* a      = (grib_accessor*)self;
     char* filename        = 0;
     char recomposed[1024] = {0,};
     char localRecomposed[1024] = {0,};
@@ -570,7 +533,7 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
     long value;
 
     if (!self->table_loaded) {
-        self->table        = load_table(self); /* may return NULL */
+        self->table        = load_table(a); /* may return NULL */
         self->table_loaded = 1;
     }
     table = self->table;
@@ -633,7 +596,7 @@ static int unpack_string(grib_accessor* a, char* buffer, size_t* len)
         return err;
 
     if (!self->table_loaded) {
-        self->table        = load_table(self); /* may return NULL */
+        self->table        = load_table(a); /* may return NULL */
         self->table_loaded = 1;
     }
     table = self->table;
@@ -642,11 +605,7 @@ static int unpack_string(grib_accessor* a, char* buffer, size_t* len)
         strcpy(tmp, table->entries[value].abbreviation);
     }
     else {
-#if 1
         snprintf(tmp, sizeof(tmp), "%d", (int)value);
-#else
-        return GRIB_DECODING_ERROR;
-#endif
     }
 
     l = strlen(tmp) + 1;
@@ -668,23 +627,38 @@ static int value_count(grib_accessor* a, long* count)
     return 0;
 }
 
+// Return true if the input is an integer (non-negative)
+static bool is_number(const char* s)
+{
+    while (*s) {
+        if (!isdigit(*s))
+            return false;
+        s++;
+    }
+    return true;
+}
+
 static int pack_string(grib_accessor* a, const char* buffer, size_t* len)
 {
+    long lValue = 0;
+    Assert(buffer);
+    if (is_number(buffer) && string_to_long(buffer, &lValue, 1) == GRIB_SUCCESS) {
+        // ECC-1654: If value is a pure number, just pack as long
+        size_t l = 1;
+        return grib_pack_long(a, &lValue, &l);
+    }
+
     grib_accessor_codetable* self = (grib_accessor_codetable*)a;
     grib_codetable* table;
-
     long i;
     size_t size = 1;
 
     typedef int (*cmpproc)(const char*, const char*);
-#ifndef ECCODES_ON_WINDOWS
+
     cmpproc cmp = (a->flags & GRIB_ACCESSOR_FLAG_LOWERCASE) ? strcmp_nocase : strcmp;
-#else
-    cmpproc cmp = (a->flags & GRIB_ACCESSOR_FLAG_LOWERCASE) ? stricmp : strcmp;
-#endif
 
     if (!self->table_loaded) {
-        self->table        = load_table(self); /* may return NULL */
+        self->table        = load_table(a); /* may return NULL */
         self->table_loaded = 1;
     }
     table = self->table;
@@ -708,10 +682,10 @@ static int pack_string(grib_accessor* a, const char* buffer, size_t* len)
         if (act->default_value != NULL) {
             const char* p = 0;
             size_t s_len  = 1;
-            long l;
+            long l = 0;
             int ret = 0;
-            double d;
-            char tmp[1024];
+            double d = 0;
+            char tmp[1024] = {0,};
             grib_expression* expression = grib_arguments_get_expression(grib_handle_of_accessor(a), act->default_value, 0);
             int type                    = grib_expression_native_type(grib_handle_of_accessor(a), expression);
             switch (type) {
@@ -729,8 +703,8 @@ static int pack_string(grib_accessor* a, const char* buffer, size_t* len)
                     s_len = sizeof(tmp);
                     p     = grib_expression_evaluate_string(grib_handle_of_accessor(a), expression, tmp, &s_len, &ret);
                     if (ret != GRIB_SUCCESS) {
-                        grib_context_log(a->context, GRIB_LOG_FATAL,
-                                         "unable to evaluate %s as string", a->name);
+                        grib_context_log(a->context, GRIB_LOG_ERROR,
+                                         "%s: Unable to evaluate default value of %s as string expression", __func__, a->name);
                         return ret;
                     }
                     s_len = strlen(p) + 1;
@@ -740,6 +714,19 @@ static int pack_string(grib_accessor* a, const char* buffer, size_t* len)
             return GRIB_SUCCESS;
         }
     }
+
+    // ECC-1652: Failed. Now do a case-insensitive compare to give the user a hint
+    for (i = 0; i < table->size; i++) {
+        if (table->entries[i].abbreviation) {
+            if (strcmp_nocase(table->entries[i].abbreviation, buffer) == 0) {
+                grib_context_log(a->context, GRIB_LOG_ERROR,
+                                 "%s: No such code table entry: '%s' "
+                                 "(Did you mean '%s'?)",
+                                 a->name, buffer, table->entries[i].abbreviation);
+            }
+        }
+    }
+
     return GRIB_ENCODING_ERROR;
 }
 
@@ -807,7 +794,7 @@ static int unpack_long(grib_accessor* a, long* val, size_t* len)
     rlen = 1; /* ECC-480 Performance: avoid func call overhead of grib_value_count */
 
     if (!self->table_loaded) {
-        self->table        = load_table(self); /* may return NULL */
+        self->table        = load_table(a); /* may return NULL */
         self->table_loaded = 1;
     }
 
